#
# spec file for package toolbox
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           toolbox
Version:        2.3+git20231030.3a6ef35
Release:        slfo.1.1.2
Summary:        Script to start a toolbox container for system debugging
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/openSUSE/microos-toolbox
Source:         microos-toolbox-%{version}.tar.xz
Requires:       (podman or docker)
Suggests:       podman
BuildArch:      noarch

%description
On systems using transactional-update it is not really possible due to
the read-only root filesystem to install tools to analyze problems in the
currently running system, a reboot is always required. Which makes it next
to impossible to debug such problems. toolbox is a small script that launches
a container to let you bring in your favorite debugging or admin tools in
such a system. The root filesystem can be found at /media/root.

%prep
%setup -q -n microos-toolbox-%{version}
%if 0%{?suse_version} == 1600
%if !0%{?is_opensuse}
sed -i -e 's,registry.opensuse.org,registry.suse.com,' toolbox
sed -i -e 's,opensuse/toolbox,suse/sl-micro/6.0/toolbox,' toolbox
%else
sed -i -e 's,opensuse/toolbox,opensuse/leap-micro/6.0/toolbox,' toolbox
%endif
%endif

%build

%install
mkdir -p %{buildroot}%{_bindir}
install -m 755 toolbox %{buildroot}%{_bindir}/toolbox

%files
%license LICENSE
%doc README.md
%{_bindir}/toolbox
%ghost %config %{_sysconfdir}/toolboxrc

%changelog
* Mon Mar 25 2024 Gustavo Yokoyama Ribeiro <gyribeiro@suse.com>
- Rename SLE-Micro to SL-Micro
* Wed Feb 28 2024 Thorsten Kukuk <kukuk@suse.com>
- Adjust image path for SLE Micro 6.0
* Mon Oct 30 2023 kukuk@suse.com
- Update to version 2.3+git20231030.3a6ef35:
  * Mount /dev/pts as mount type=devpts instead of --volume
  * fix typo creat -> create
  * Remove trailing whitespace
  * Fix bash error when container cannot be pulled
* Mon May  8 2023 Danish Prakash <danish.prakash@suse.com>
- Update EOL *-micro images to supported versions. (bsc#1211018)
* Tue Jun 28 2022 Thorsten Kukuk <kukuk@suse.com>
- Prefer podman as container runtime
  (unrelated part of [bnc#1200976])
* Wed Jun 22 2022 kukuk@suse.com
- Update to version 2.3+git20220622.32785f7:
  * Only set --userns=keep-id when running rootless
* Fri Jun  3 2022 kukuk@suse.com
- Update to version 2.3+git20220603.bbeda2e:
  * Allow to choose runtime and try to retain the user's groups
  * (Try to) Avoid problems when packages touching bind mounts are upgraded
  * Try to make sure that (some) foreign distro images (kind of) work as toolboxes
  * Do not stop a toolbox with something running inside
  * Exit if neither podman or docker are usable
  * Support passing just the name of the container to create and enter command
  * Fix cleanup logic and make toolbox start a little less verbose
  * Always pull when creating a new toolbox
  * Add a "more sandboxing" mode
* Mon Feb 21 2022 jsrain@suse.com
- adjusted the patch to the toolbox container in registry
* Wed Jan 26 2022 Jan Zerebecki <jan.suse@zerebecki.de>
- Allow docker as an alternative to podman in the package Requires. This was
  supported since 2.2.
* Mon Jan 17 2022 kukuk@suse.com
- Update to version 2.3+git20220117.bd53c7c:
  - Fixes error where if custom image is used toolbox will download
    the default image before entering an existing container. (#40)
* Wed Nov 24 2021 kukuk@suse.com
- Update to version 2.2+git20211124.09791b1:
  * Introduce -n/--nostop switch so mutiple sessions can be run inside an existing toolbox
* Mon Nov  8 2021 Ludwig Nussel <lnussel@suse.de>
- Don't install config file in /etc in favor of a built-in default. Avoids
  empty /etc pulling wrong image.
- Handle Leap Micro (boo#1192474)
* Mon Aug 23 2021 kukuk@suse.com
- Update to version 2.2+git20210823.dd0fff8:
  * README mini-typo
  * Docker: don't use unsupported --userns=keep-id
  * Docker: also check for created status
  * Try to use docker if installed and podman is not
  * Properly share namespaces in non-user toolboxes
  * Properly quote workdir
* Mon Mar 29 2021 kukuk@suse.com
- Update to version 2.1+git20210329.d14ac82:
  * Fix localtime and mount sys, e.g., for tracing
  * Fix 'toolbox list' returning an error code even if working
* Thu Mar 11 2021 kukuk@suse.com
- Update to version 2.1+git20210311.15cb3ad:
  * Don't check for subuid if root calls toolbox [bsc#1183375]
* Fri Mar  5 2021 kukuk@suse.com
- Update to version 2.1+git20210305.ca2bc53:
  * Avoid copying the user setup script with 'podman cp'
* Fri Feb 26 2021 kukuk@suse.com
- Update to version 2.1+git20210226.daeb191:
  * Set trap only after option parsing (#22)
* Thu Feb 25 2021 kukuk@suse.com
- Update to version 2.1+git20210225.5c541c8:
  * Check sub{u,g}id if rootless, and fail early if they're not setup
  * Fix creating a container with a specific name with `-c`
* Mon Feb  8 2021 kukuk@suse.com
- Update to version 2.1+git20210208.a720b25:
  * Alleviate the need for zypper in the user toolbox script
  * Consolidate logging and help debugging of the user toolbox's script
  * Export machine-id and IPC inside the toolbox (IPC, user only)
  * Fix (more) formatting...
* Wed Feb  3 2021 kukuk@suse.com
- Update to version 2.1+git20210203.a669e3a:
  * Fix formatting
  * Enhance alternate UI docu
  * Ignore podman runlabel error if no RUN label exist
  * Enhance documentation
  * Check existence of volume directories (#15)
* Mon Jan 25 2021 kukuk@suse.com
- Update to version 2.0+git20210125.50611db:
  * Document configuration files, add /usr/etc/toolboxrc
  * Update README to include commands
  * Update the README
  * Be even more compatible with Silverblue Toolbox
  * Introduce commands, for compatibility with Silverblue's toolbox
  * Mount /run/media and and /tmp inside a user toolbox
  * Export more env variables inside (user) toolboxes
* Wed Jan 20 2021 Thorsten Kukuk <kukuk@suse.com>
- Add a group tag for SLE Micro
- Mark toolboxrc as %%config and add it is Source
* Tue Jan 19 2021 bruno.leon@suse.com
- Update to version 1.0+git20210119.b5acdcf:
  * Dynamically set REGISTRY and IMAGE (#11)
* Thu Nov 26 2020 kukuk@suse.com
- Update to version 1.0+git20201126.3d26283:
  * Make it easier to use custom images (#10)
  * Update toolbox doc (#9)
* Wed Sep  2 2020 kukuk@suse.com
- Update to version 1.0+git20200831.d2d2e5d:
  * Allow graphical applications from inside a user toolbox to run
* Mon Aug  3 2020 kukuk@suse.com
- Update to version 1.0+git20200803.7ff20b6:
  * Connect to the host's SSH agent in user toolboxes.
  * Stay in current directory, even when entering a toolbox
  * Use the toolbox name as the actual toolbox's hostname
* Wed Mar 25 2020 kukuk@suse.com
- Update to version 1.0+git20200324.dd047bc:
  * fix entering a toolbox if something changed in /dev since creation
* Mon Feb 17 2020 kukuk@suse.com
- Update to version 1.0+git20200217.cd18bfb:
  * Multiple toolboxes, with different names
  * Configure `sudo` access for an user toolbox
  * Correctly setup the user
  * Add -u|--user parameter
  * Handle arguments with 'getopt'
* Mon Oct 14 2019 kukuk@suse.com
- Update to version 1.0+git20191014.3034fbc:
  * Make default shell configureable, use /bin/bash as default
* Mon Oct  7 2019 kukuk@suse.com
- Update to version 1.0+git20191007.e038337:
  * Initial version
